



if exist %PREFIX%\\Library\\include\\irrlicht\irrlicht.h (exit 0) else (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist $PREFIX$\\Library\\lib\\Irrlicht.lib (exit 0) else (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if exist $PREFIX$\\Library\\bin\\Irrlicht.dll (exit 0) else (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
